use Test::More;
use strict;

use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::IGFS::API::Soap::Batch::Data;
use DE_EPAGES::IGFS::API::Soap::Batch::Confirmation;

use constant EXPECTED => '5,,,,978,12345,,,aaaaaa,123456.00,1234567,,,,,';

sub NoConfirmation {
    my $file = DE_EPAGES::IGFS::API::Soap::Batch::Data->new;
    isa_ok( $file, 'DE_EPAGES::IGFS::API::Soap::Batch::Data', 'batch file constuctor' );
    is( $file->data, '', 'undefined confirmations' ),;
    $file = DE_EPAGES::IGFS::API::Soap::Batch::Data->new( 'confirmations' => [] );
    is( $file->data, '', 'empty confirmations' );
}

sub OneConfirmation {
    my $values = {
        'transID'     => '12345',
        'shopUserRef' => 'aaaaaa',
        'amount'      => '123456.00',
        'trackID'     => '1234567',
    };
    my $conf  = DE_EPAGES::IGFS::API::Soap::Batch::Confirmation->new( %{$values} );
    my @confs = ($conf);
    my $file  = DE_EPAGES::IGFS::API::Soap::Batch::Data->new( 'confirmations' => \@confs );
    is( $file->data, EXPECTED, 'one corfirmation' );
}

sub TwoConfirmations {
    my $values = {
        'transID'     => '12345',
        'shopUserRef' => 'aaaaaa',
        'amount'      => '123456.00',
        'trackID'     => '1234567',
    };

    my $conf = DE_EPAGES::IGFS::API::Soap::Batch::Confirmation->new( %{$values} );

    my @confs = ( $conf, $conf );
    my $file = DE_EPAGES::IGFS::API::Soap::Batch::Data->new( 'confirmations' => \@confs );
    is( $file->data, EXPECTED . "\n" . EXPECTED, 'two confirmations' );
}

sub Main {
    NoConfirmation;
    OneConfirmation;
    TwoConfirmations;
    done_testing;
    return;
}

RunScript( Sub => \&Main );

1;
