use Test::More;
use strict;

use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::IGFS::API::Soap::Batch::PaymentOutcome;

use constant GUID => '4E40ED9C-2240-9252-EA00-C0A8027FC099';

sub parser {
    my $data = <<"EOS";
5,,,,978,3060278630259179,,,m.mustermann\@epages.de,40.9,4E4B7F5E-253C-AD00-4C6C-C0A8027F789F,,,,,,1,,CAPTURED,NA,74870,NA,NA,20110817,NA,3060278640807229,76018881,NA
5,,,,978,221107939100223691,,,m.mustermann\@epages.de,23.95,4E40ED9C-2240-9252-EA00-C0A8027FC099,,,,,,0,ORIGINAL TRANSACTION NOT PRESENT,NOT CAPTURED,NA,,NA,NA,,,,,

--uuid:cc14f9dc-87a4-4f3a-88f4-8ece9d4eb753--
EOS

    my $po = DE_EPAGES::IGFS::API::Soap::Batch::PaymentOutcome->new(
        'data'         => $data,
        'payment_GUID' => GUID
    );

    is( $po->trtype(),      '5',                                    'trtype' );
    is( $po->currency(),    '978',                                  'currency' );
    is( $po->tranid(),      '221107939100223691',                   'tranid' );
    is( $po->shopuserref(), 'm.mustermann@epages.de',               'shopuserref' );
    is( $po->amount,        '23.95',                                'amount' );
    is( $po->trackid(),     '4E40ED9C-2240-9252-EA00-C0A8027FC099', 'trackid' );
    is( $po->rc,            '0',                                    'rc' );
    is( $po->desc,          'ORIGINAL TRANSACTION NOT PRESENT',     'desc' );
    is( $po->result,        'NOT CAPTURED',                         'result' );
    is( $po->refid,         '',                                     'refid' );

    $po = DE_EPAGES::IGFS::API::Soap::Batch::PaymentOutcome->new(
        'data'         => $data,
        'payment_GUID' => '4E4B7F5E-253C-AD00-4C6C-C0A8027F789F',
    );

    is( $po->trtype(),      '5',                                    'trtype' );
    is( $po->currency(),    '978',                                  'currency' );
    is( $po->tranid(),      '3060278630259179',                     'tranid' );
    is( $po->shopuserref(), 'm.mustermann@epages.de',               'shopuserref' );
    is( $po->amount,        '40.9',                                 'amount' );
    is( $po->trackid(),     '4E4B7F5E-253C-AD00-4C6C-C0A8027F789F', 'trackid' );
    is( $po->rc,            '1',                                    'rc' );
    is( $po->desc,          '',                                     'desc' );
    is( $po->result,        'CAPTURED',                             'result' );
    is( $po->refid,         '74870',                                'refid' );
    is( $po->transdate(),   '20110817',                             'transdate' );
    is( $po->newtransid(),  '3060278640807229',                     'newtransid' );
    is( $po->termid(),      '76018881',                             'termid' );
}

sub Main {
    parser;
    done_testing;
    return;
}

RunScript( Sub => \&Main );

1;
