use strict;
use warnings;
use Test::More;

use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Database::API::Connection
    qw( GetTestSite RunOnStore ConnectTestSite DisconnectSite );
use DE_EPAGES::Object::API::Factory qw (LoadObjectByPath);

=head1 ros.t - Run On Store

Running tests on a store takes a long time, which is bad for the test suite.
So all tests that need to be run on the database should go here.

Test subroutines are pushed into the array.
The code for executing them is at the bottom.

=head2 Test pathfile generation

The pathfile is an important part of the SipsAtos business.
(Docs on the pathfile might be available elsewhere.)
Perform some rudimentary checks on this pathfile.

=cut

my @subs; # subroutines containing test code

push @subs, sub {
    my $Shop = LoadObjectByPath( '/Shops/DemoShop' );
    my $pms = $Shop->get('PaymentMethods');
    my $found;
    foreach my $pm ( @$pms ) {
        my $type = $pm->get('PaymentType')->alias;
        # diag $type;
        if ( $type eq 'SipsAtos') {
            $found++;
            my $filename = $pm->get('SipsAtosPathfile');
            diag $filename;
            my $slashcount = $filename =~ tr#/#/#;
            if ( $^O eq 'MSWin32' ) { ok ! $slashcount,  "no slashes on $^O" }
            else                    { ok   $slashcount, "got slashes on $^O" }
            my $cont = $pm->get('SipsAtosPathfileContent');
            diag $cont;
        }
    }
    diag 'SipsAtos payment method not found (not configured?)'
        unless $found;
};

push @subs, sub { ok 1, q(hier geht's weiter) };

RunScript( Debug => 1, Sub => sub {
    ConnectTestSite();
    # GetTestSite = database; not the same as $Object->getSite (= shop)
    RunOnStore( Store => GetTestSite(), Sub => sub { $_->() for @subs } );
    DisconnectSite();
});

done_testing;
