## no critic(ProhibitMixedBooleanOperators)
use strict;
use warnings;
use Test::More;
use Test::Exception;
use DateTime;

BEGIN { # make package alias
    *Sips:: = *DE_EPAGES::SipsAtos::UI::PaymentMethodSipsAtos:: ;
}

# ==== a warning during loading would indicate a logo problem ==========
{   # Load module and check that no warning is issued.
    open my $fh, '>', \my $buf or 'ignore'; # fool critic
    local *STDERR = $fh;
    ## no critic(ProhibitStringyEval)
    eval q(use DE_EPAGES::SipsAtos::UI::PaymentMethodSipsAtos);
    close $fh or 'ignore';
    ok ! $buf, 'no warning during load' or diag $buf;
}

# ==== logos should have been found during load ========================
my @logos;
while ( my($key, $file) = each %Sips::CreditCardLogos ) {
    my %entry = ( name => $file, value => $key );
    $entry{checked} = 1;
    push @logos, \%entry;
}
ok scalar @logos, 'at least one logo has been found';
# diag explain \@logos;
is ref $logos[0], 'HASH', 'correct structure';
ok exists $logos[0]->{$_}, "has $_" for qw/name value/;

# ==== test utility subroutine =========================================

my @numstr = qw(
20110821
201108211740
20110821174055
);

dies_ok { Sips::numStrToDateTime( 'Gurkensalat' ) } 'deadly Gurkensalat :)';

for ( @numstr ) {
    my( $dt, $d2 );
    lives_ok { $dt = Sips::numStrToDateTime( $_ ) } 'construction';
    isa_ok $dt, 'DateTime';
    0 and diag $dt;
    lives_ok { $d2 = Sips::numStrToDateTime( $_, undef ) } "c'tor with undef";
    isa_ok $d2, 'DateTime';
    0 and diag $d2;
    is $dt->epoch, $d2->epoch, 'additional undef does not alter the outcome';
}

# ==== nothing else matters (for now) ==================================

done_testing;
