#-*- Makefile -*-

require DE_EPAGES::Core::API::Makefile;
__DATA__

!include host-$(HOSTNAME).mk

PATCH_TAG	= patch_6_12_2
PATCH_VERSION	= 6.12.2
PATCH_LEVEL	= 2
DE_EPAGES_DIR	= $(EPAGES_CARTRIDGES)\DE_EPAGES
DE_EPAGES_NEW	= $(EPAGES_CARTRIDGES)\.version\$(PATCH_VERSION)\DE_EPAGES
DATA_DIR	= $(EPAGES_SHARED)\Patches\var-$(PATCH_TAG)
LOG_DIR		= $(DATA_DIR)\logs\$(HOSTNAME)
TGT		= $(DATA_DIR)\tgt\$(HOSTNAME)
BACKUP_DIR	= $(DATA_DIR)\backup\$(HOSTNAME)
BACKUP_DB	= 1
LIMIT_HTTPD	= 1

MARGS		= BACKUP_DIR=$(BACKUP_DIR) BACKUP_DB=$(BACKUP_DB) LIMIT_HTTPD=$(LIMIT_HTTPD)
!OS_SPECIFIC_DEFINES
PRL		= $(PERL) -IInclude
INCLUDES	= -I$(EPAGES_CARTRIDGES)/.version/$(PATCH_VERSION)
!ifdef WINDOWS
IF_EXIST	= if exist
IF_NOT_EXIST	= if not exist
DO		=
RMDIR		= rmdir /S /Q
DIFF		= gdiff
CHANGE_ETC	= 0
MAKE		= nmake -nologo $(MARGS)
!else
IF_EXIST	= [ ! -e
IF_NOT_EXIST	= [ -e
DO		= ] ||
RMDIR		= rm -rf
DIFF		= diff
EPAGES_PROJECT	?= epages6
CHANGE_ETC	= 1
EPAGES_ETC	= $(shell dirname "$(EPAGES)")\etc
MAKE		= make $(MARGS)
!endif

LOOP_STORES	= $(PRL) Scripts/LoopStores.pl
MOVE_DIR	= use DE_EPAGES::Core::API::File qw(RenameDirectory); RenameDirectory
SYBASE_DUMPS 	= $(PRL) $(DE_EPAGES_DIR)/Database/Scripts/DatabaseDumps.pl
MYSQL_DUMPS 	= $(PRL) _CARTRIDGES_/DE_EPAGES/Database/Scripts/MySQLDumps.pl
START_SERVICE   = $(PRL) $(DE_EPAGES_DIR)/Installer/Scripts/startService.pl -ifexists
STOP_SERVICE    = $(PRL) $(DE_EPAGES_DIR)/Installer/Scripts/stopService.pl -ifexists
CREATE_CTMPLS   = $(PRL) $(DE_EPAGES_DIR)/Presentation/Scripts/createCtmpls.pl

!ifeq ("$(PATCH_LEVEL)", "0")
SINGLE_HOST_DUMP =
!else
SINGLE_HOST_DUMP = -all
!endif

STORE		= dummy

.force:

# we always need following target for patch.pl:
get_var: .force
	@echo LOG_DIR=$(LOG_DIR)
	@echo BACKUP_DIR=$(BACKUP_DIR)
	@echo TGT_DIR=$(DATA_DIR)\tgt
	@echo TGT=$(TGT)

# how to install the epages patch (see install_en.txt)
# ****************************************************
#-------------------------------------------------------------------------------------------
#    | execute                             | on  UNIX                  | on Windows        |
#-------------------------------------------------------------------------------------------
# 1. | set environment                     | . /etc/default/epages6    |                   |
# 2. | create makefile (needs epages perl) | perl Makefile.PL          | perl Makefile.PL  |
# 3. | pre-installation tasks              | make preinstall           | nmake preinstall  |
# 4. | set environment                     | . /etc/default/epages6    |                   |
# 5. | installation tasks* (see NOTE)      | make install              | nmake install     |
#-------------------------------------------------------------------------------------------
# *) if epages runs on more than 1 computer, execute this step only on your main application server

prepare: $(DATA_DIR)\tgt\prepare
$(DATA_DIR)\tgt\prepare:
	$(MKDIR) $(TGT)
	$(MKDIR) $(BACKUP_DIR)
	$(MAKE) preinstall_versions
	$(MAKE) touch DIR=$(@D) ADDF=$(@F)

preinstall: $(TGT)\preinstall
$(TGT)\preinstall:
	$(MAKE) stop_epages limit_httpd stop_cron add_mysql_group initial_backup_db
	$(DEL) $(DATA_DIR)\tgt\posthosts.txt
	$(PRL) Scripts/checkScheduler.pl -hostname $(HOSTNAME)
	$(AWK) "/^$(HOSTNAME)$$/{i=1}END{exit i!=1}" $(DATA_DIR)\tgt\prehosts.txt 2>$(NUL) || echo $(HOSTNAME)>> $(DATA_DIR)\tgt\prehosts.txt
	$(MAKE) touch DIR=$(@D) ADDF=$(@F)

install: $(DATA_DIR)\tgt\prepare $(TGT)\preinstall patch_files restart_epages patch update_ctmpls
	echo $(HOSTNAME)> $(DATA_DIR)\tgt\alphahost.txt
	$(IF_EXIST) $(TGT)\restore_style $(DO) $(RMDIR) $(TGT)\restore_style
	$(MAKE) touch DIR=$(DATA_DIR)\tgt ADDF=install DELF=restore
	$(PERL) -MFile::Compare -e "exit not compare('$(DATA_DIR)\tgt\alphahost.txt','$(DATA_DIR)\tgt\prehosts.txt')"\
 || $(MAKE) postinstall NO_RESTART=1 IS_ALPHA=1 POSTINSTALL_COMPLETE=1
	$(MAKE) perm

postinstall:
!ifdef IS_ALPHA
!ifneq ("$(POSTINSTALL_COMPLETE)", "1")
	@echo "Postinstall on alpha server failed: First postinstall all other servers."
	@$(PERL) -e "exit 1;"
!endif
!ifndef NO_RESTART
	$(MAKE) restart_epages
!endif
!else
	$(MAKE) patch_files
	$(MAKE) perm
!endif
	$(MAKE) $(DATA_DIR)\tgt\install final_backup_db start_cron new/unlimit_httpd start_epages configure_apache update_repo CONFIGURE_HTTPD=1
!ifdef IS_ALPHA
	$(MAKE) open_stores
	$(MAKE) sync_stores
	$(PRL) Scripts/findOverloadedTemplates.pl -store all -patchdir . -initial $(INITIAL_VERSION)
!endif
	echo $(HOSTNAME)>> $(DATA_DIR)\tgt\posthosts.txt

# how to restore the prevoius epages version (see install_en.txt)
# ***************************************************************
#-------------------------------------------------------------------------------------------
#    | execute                             | on  UNIX                  | on Windows        |
#-------------------------------------------------------------------------------------------
# 1. | set environment                     | . /etc/default/epages6    |                   |
# 2. | create makefile (needs epages perl) | perl Makefile.PL          | perl Makefile.PL  |
# 3. | pre-restore tasks                   | make prerestore           | nmake prerestore  |
# 4. | restore tasks* (see NOTE)           | make restore              | nmake restore     |
# 5. | set environment                     | . /etc/default/epages6    |                   |
#-------------------------------------------------------------------------------------------
# *) if epages runs on more than 1 computer, execute this step only on your main application server

prerestore:
	$(MAKE) stop_epages restore_files new/limit_httpd stop_cron restart_epages restore_db

restore: prerestore
	$(IF_EXIST) $(DATA_DIR)\tgt\patchByVersion $(DO) $(RMDIR) $(DATA_DIR)\tgt\patchByVersion
	$(IF_EXIST) $(TGT)\patch_store $(DO) $(RMDIR) $(TGT)\patch_store
	$(IF_EXIST) $(TGT)\sync_store $(DO) $(RMDIR) $(TGT)\sync_store
	$(IF_EXIST) $(TGT)\test_style $(DO) $(RMDIR) $(TGT)\test_style
	$(IF_EXIST) $(TGT)\create_ctmpl $(DO) $(RMDIR) $(TGT)\create_ctmpl
	$(IF_EXIST) $(TGT)\update_ctmpl $(DO) $(RMDIR) $(TGT)\update_ctmpl
	$(MAKE) update_ctmpls DEL_SAVED_INCLUDES=1
	$(IF_EXIST) $(TGT)\update_ctmpl $(DO) $(RMDIR) $(TGT)\update_ctmpl
	$(MAKE) start_epages
	$(MAKE) restore_styles
	$(MAKE) start_cron
	$(MAKE) touch DIR=$(DATA_DIR)\tgt ADDF=restore DELF=install
	$(MAKE) postrestore perm IS_ALPHA=1

postrestore: $(DATA_DIR)\tgt\restore
	$(DEL) $(TGT)\preinstall
	$(DEL) $(DATA_DIR)\tgt\prehosts.txt
	$(DEL) $(DATA_DIR)\tgt\alphahost.txt
!ifdef IS_ALPHA
	$(MAKE) open_stores
!else
	$(MAKE) start_cron start_epages
!endif
	$(MAKE) unlimit_httpd
	$(IF_EXIST) $(TGT)\sync_store $(DO) $(RMDIR) $(TGT)\sync_store

# main targets (patch files)
# ==========================

patch_files:
!ifeq ("$(CHANGE_CONFIG)", "1")
	$(MAKE) Config\patch
!endif
!ifeq ("$(CHANGE_CARTRIDGES)", "1")
	$(MAKE) Cartridges\patch
!endif
!ifeq ("$(CHANGE_APACHE)", "1")
	$(MAKE) patch_apache
!endif
!ifeq ("$(PATCH_LEVEL)", "0")
!ifeq ("$(CHANGE_SERVICE)", "1")
	$(MAKE) Service\patch
!endif
!ifeq ("$(CHANGE_REQROUTER)", "1")
	$(MAKE) RequestRouter\patch
!endif
!ifeq ("$(CHANGE_ETC)", "1")
	$(MAKE) etc\patch
!endif
!ifeq ("$(CHANGE_WEBADAPTER)", "1")
	$(MAKE) WebAdapter\patch
!endif
!endif
!ifeq ("$(CHANGE_BIN)", "1")
	$(MAKE) bin\patch
!endif
!ifeq ("$(CHANGE_WEBROOT)", "1")
	$(MAKE) WebRoot\patch
!endif
!ifeq ("$(CHANGE_STORES)", "1")
	$(PRL) Scripts/patch_shared.pl -cp Stores -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION)
	$(DEL) "$(EPAGES_STORES)"\.$(PATCH_VERSION)-restore
	$(MAKE) touch DIR="$(EPAGES_STORES)" ADDF=.$(PATCH_VERSION)-patch
!ifdef INITIAL_VERSION_LT_6012001000
	$(DEL) $(EPAGES_STORES)\*\javascript\jQuery\core.js
	$(DEL) $(EPAGES_STORES)\*\javascript\jQuery\ui\widget.js
!endif
!ifndef WINDOWS
	chmod 640 "$(EPAGES_STORES)"/.$(PATCH_VERSION)-patch
	chown $${EPAGES_APPUSER:-eprunapp}:epages "$(EPAGES_STORES)"/.$(PATCH_VERSION)-patch
!endif
!endif

restore_files:
!ifeq ("$(CHANGE_PERL)", "1")
	$(MAKE) Perl\restore
!endif
!ifeq ("$(PATCH_LEVEL)", "0")
!ifeq ("$(CHANGE_SERVICE)", "1")
	$(MAKE) Service\restore
!endif
!ifeq ("$(CHANGE_REQROUTER)", "1")
	$(MAKE) RequestRouter\restore
!endif
!ifeq ("$(CHANGE_WEBADAPTER)", "1")
	$(MAKE) WebAdapter\restore
!endif
!ifeq ("$(CHANGE_ETC)", "1")
	$(MAKE) etc\restore
!endif
!endif
!ifeq ("$(CHANGE_BIN)", "1")
	$(MAKE) bin\restore
!endif
!ifeq ("$(CHANGE_WEBROOT)", "1")
	$(MAKE) WebRoot\restore
!endif
!ifeq ("$(CHANGE_STORES)", "1")
	$(MAKE) Stores\restore
!endif
!ifeq ("$(CHANGE_CONFIG)", "1")
	$(MAKE) Config\restore
!endif
!ifeq ("$(CHANGE_CARTRIDGES)", "1")
	$(MAKE) Cartridges\restore
!endif

# main targets (patch database)
# =============================

# backup databases
add_mysql_group:
!ifndef WINDOWS
!ifdef INITIAL_VERSION_LT_6012000000
!ifdef MYSQL_CLIENT
	sh Scripts/$@.sh $(PREREQ_INI)
!endif
!endif
!endif

initial_backup_db: $(TGT)\initial_backup_db
final_backup_db: $(TGT)\final_backup_db
$(TGT)\initial_backup_db $(TGT)\final_backup_db full_backup_db:
!ifneq ("$(BACKUP_DB)", "")
!ifeq ("$(MYSQL_DATASOURCE)", "1")
	$(MYSQL_DUMPS) $(SINGLE_HOST_DUMP) -target $@
!endif
!ifeq ("$(SYBASE_DATASOURCE)", "1")
	$(SYBASE_DUMPS) $(SINGLE_HOST_DUMP) -target $@
!endif
!endif

# install the patch
patch: patch_site patch_stores update_cartridge_dir patch_pooldb patch_version

# restore databases
restore_db: $(TGT)\restore_db
$(TGT)\restore_db:
!ifneq ("$(BACKUP_DB)", "")
!ifeq ("$(SYBASE_RUNS)", "1")
	$(SYBASE_DUMPS) -target $@
!endif
!ifeq ("$(MYSQL_DATASOURCE)", "1")
	$(MYSQL_DUMPS) -own -target $@
!else
!ifneq ("$(SYBASE_RUNS)", "1")
	$(MAKE) touch DIR=$(@D) ADDF=$(@F) DELF=initial_backup_db
	$(DEL) $(@D)\final_backup_db
!endif
!endif
!endif

# targets (patch files)
# *********************

# patch: etc

etc\patch: $(EPAGES_ETC)\.$(PATCH_VERSION)-patch
$(EPAGES_ETC)\.$(PATCH_VERSION)-patch:
	$(PRL) Scripts/patch_files.pl -patch etc -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION)
	sh Scripts/patch_etc.sh -P "$(EPAGES_PROJECT)" -i "$(INITIAL_INTERNAL_VERSION)" -p $(PATCH_TAG) -b "$(BACKUP_DIR)"

etc\restore: $(EPAGES_ETC)\.$(PATCH_VERSION)-restore
$(EPAGES_ETC)\.$(PATCH_VERSION)-restore:
	$(PRL) Scripts/patch_files.pl -restore etc -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION)
	sh Scripts/patch_etc.sh -R -P "$(EPAGES_PROJECT)" -i "$(INITIAL_INTERNAL_VERSION)" -p $(PATCH_TAG) -b "$(BACKUP_DIR)"

# patch: bin

bin\patch: $(EPAGES)\bin\.$(PATCH_VERSION)-patch
$(EPAGES)\bin\.$(PATCH_VERSION)-patch:
!ifdef WINDOWS
	$(PRL) Scripts/patch_files.pl -patch bin -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION)
!else
	$(PRL) Scripts/patch_files.pl -patch bin -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION)
!endif

bin\restore: $(EPAGES)\bin\.$(PATCH_VERSION)-restore
$(EPAGES)\bin\.$(PATCH_VERSION)-restore:
	$(PRL) Scripts/patch_files.pl -restore bin -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION)

# patch: Service

Service\patch: $(EPAGES)\Service\.$(PATCH_VERSION)-patch
$(EPAGES)\Service\.$(PATCH_VERSION)-patch:
	$(PRL) Scripts/patch_files.pl -patch Service -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION)

Service\restore: $(EPAGES)\Service\.$(PATCH_VERSION)-restore
$(EPAGES)\Service\.$(PATCH_VERSION)-restore:
	$(PRL) Scripts/patch_files.pl -restore Service -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION)

# patch: RequestRouter

RequestRouter\patch: $(EPAGES)\RequestRouter\.$(PATCH_VERSION)-patch
$(EPAGES)\RequestRouter\.$(PATCH_VERSION)-patch:
	$(PRL) Scripts/patch_files.pl -patch RequestRouter -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION)

RequestRouter\restore: $(EPAGES)\RequestRouter\.$(PATCH_VERSION)-restore
$(EPAGES)\RequestRouter\.$(PATCH_VERSION)-restore:
	$(PRL) Scripts/patch_files.pl -restore RequestRouter -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION)

# patch: WebAdapter

WebAdapter\patch: $(EPAGES)\WebAdapter\.$(PATCH_VERSION)-patch
$(EPAGES)\WebAdapter\.$(PATCH_VERSION)-patch:
	$(PRL) Scripts/patch_files.pl -patch WebAdapter -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION)
!ifndef WINDOWS
	cat linux/WebAdapter/zzz-epages-httpd.conf.ept > "$(EPAGES)"/WebAdapter/zzz-epages-httpd.conf.ept
!endif

WebAdapter\restore: $(EPAGES)\WebAdapter\.$(PATCH_VERSION)-restore
$(EPAGES)\WebAdapter\.$(PATCH_VERSION)-restore:
	$(PRL) Scripts/patch_files.pl -restore WebAdapter -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION)

# patch: Cartridges

Cartridges\patch: $(EPAGES_CARTRIDGES)\.$(PATCH_VERSION)-patch
$(EPAGES_CARTRIDGES)\.$(PATCH_VERSION)-patch:
	$(MAKE) close_stores
	$(MAKE) touch DIR=$(@D) ADDF=$(@F) DELF=.$(PATCH_VERSION)-restore

Cartridges\restore: $(EPAGES_CARTRIDGES)\.$(PATCH_VERSION)-restore
$(EPAGES_CARTRIDGES)\.$(PATCH_VERSION)-restore:
	$(MAKE) close_stores
	$(PRL) -I"$(EPAGES_CARTRIDGES)\.version\$(PATCH_VERSION)" Scripts/buildCartridgeVersionFolders.pl\
 -restore -initial $(INITIAL_VERSION) -final $(PATCH_VERSION) -ini $(PREREQ_INI)
	$(MAKE) touch DIR=$(@D) ADDF=$(@F) DELF=.$(PATCH_VERSION)-patch

# patch: Perl

Perl\patch: $(EPAGES_PERL)\.$(PATCH_VERSION)-patch
$(EPAGES_PERL)\.$(PATCH_VERSION)-patch:
!ifdef INITIAL_VERSION_LT_6012001000
	$(PRL) Scripts/CartridgesBin2PerlBin.pl
!endif
!ifdef INITIAL_VERSION_LT_6012002000
!ifndef WINDOWS
	$(COPY) linux/Perl/man/man8 $(EPAGES_PERL)/man
	chown -R ep_appl:epages $(EPAGES_PERL)/man/man8
	chmod 755 $(EPAGES_PERL)/man/man8
	chmod 644 $(EPAGES_PERL)/man/man8/*
!endif
!endif
	$(MAKE) touch DIR=$(@D) ADDF=$(@F) DELF=.$(PATCH_VERSION)-restore

Perl\restore: $(EPAGES_PERL)\.$(PATCH_VERSION)-restore
$(EPAGES_PERL)\.$(PATCH_VERSION)-restore:
	$(MAKE) touch DIR=$(@D) ADDF=$(@F) DELF=.$(PATCH_VERSION)-patch

# patch: Apache

patch_apache:
!ifndef WINDOWS
!ifdef NOTHING_TODO
!endif
!endif

# patch: WebRoot

WebRoot\patch: $(EPAGES_WEBROOT)\.$(PATCH_VERSION)-patch
$(EPAGES_WEBROOT)\.$(PATCH_VERSION)-patch:
	$(PRL) Scripts/patch_files.pl -patch WebRoot -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION) -ignore "StoreTypes Doc"
!ifeq ("$(PATCH_LEVEL)", "0")
	$(PRL) Scripts/patch_files.pl -patch Monitor -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION)
!endif

WebRoot\restore: $(EPAGES_WEBROOT)\.$(PATCH_VERSION)-restore
$(EPAGES_WEBROOT)\.$(PATCH_VERSION)-restore:
	$(PRL) Scripts/patch_shared.pl -rm WebRoot -version $(PATCH_VERSION)
	$(PRL) Scripts/patch_files.pl -restore WebRoot -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION) -alpha "$(IS_ALPHA)"
	$(IF_EXIST) "$(EPAGES_WEBROOT)\StoreTypes\$(PATCH_VERSION)" $(DO) $(RMDIR) "$(EPAGES_WEBROOT)\StoreTypes\$(PATCH_VERSION)"
	$(DEL) $(DATA_DIR)\tgt\preinstall_versions
	$(DEL) $(DATA_DIR)\tgt\prepare
!ifeq ("$(PATCH_LEVEL)", "0")
	$(PRL) Scripts/patch_files.pl -restore Monitor -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION)
!endif

# patch: Stores

Stores\restore: $(EPAGES_STORES)\.$(PATCH_VERSION)-restore
$(EPAGES_STORES)\.$(PATCH_VERSION)-restore:
	$(PRL) Scripts/patch_shared.pl -rm Stores -version $(PATCH_VERSION)
	$(PRL) Scripts/patch_files.pl -restore Stores -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION) -alpha "$(IS_ALPHA)"

# patch: Config

Config\patch: $(EPAGES_CONFIG)\.$(PATCH_VERSION)-patch
$(EPAGES_CONFIG)\.$(PATCH_VERSION)-patch:
	$(PRL) Scripts/patch_files.pl -patch Config -backuponly "$(BACKUP_DIR)" -version $(PATCH_VERSION)
	$(PRL) Scripts/PatchConfig.pl -source Shared/Config -target "$(EPAGES_CONFIG)" -md5sum md5sum.ini -version $(PATCH_VERSION)
!ifdef INITIAL_VERSION_LT_6012002000
	$(PRL) Scripts/EditSchedulerConf.pl -merge Shared/Config/merge-Scheduler.conf-patch
!endif
!ifdef INITIAL_VERSION_LT_6012000000
	$(PRL) Scripts/EditServletConf.pl -version $(PATCH_VERSION)
!endif
!ifdef INITIAL_VERSION_LT_6010004000
	$(PRL) Scripts/ConfigureMailDebug.pl
!endif

Config\restore: $(EPAGES_CONFIG)\.$(PATCH_VERSION)-restore
$(EPAGES_CONFIG)\.$(PATCH_VERSION)-restore:
	$(PRL) Scripts/patch_files.pl -restore Config -backup "$(BACKUP_DIR)" -version $(PATCH_VERSION) -alpha "$(IS_ALPHA)"
	$(IF_EXIST) "$(EPAGES_CONFIG)\StoreTypes.d\$(PATCH_VERSION)" $(DO) $(RMDIR) "$(EPAGES_CONFIG)\StoreTypes.d\$(PATCH_VERSION)"

# targets (patch database)
# ************************

close_stores: loop_stores.mak
	$(MAKE) make_makefile
!ifndef EPAGES_IGNORE_SITE
	$(CD) $(DE_EPAGES_DIR) && $(MAKE) close_store STORE=Site STORE_TYPE=Site
!endif
	$(MAKE) -f loop_stores.mak close_stores TGT="$(TGT)"
close_store:
	$(CD) $(DE_EPAGES_DIR) && $(MAKE) close_store STORE=$(STORE) STORE_TYPE=$(STORE_TYPE)
	$(DEL) $(TGT)\open_store\$(STORE)

open_stores: loop_stores.mak
	$(MAKE) make_makefile
!ifndef EPAGES_IGNORE_SITE
	$(CD) $(DE_EPAGES_DIR) && $(MAKE) open_store STORE=Site STORE_TYPE=Site
!endif
	$(MAKE) -f loop_stores.mak open_stores TGT="$(TGT)"
open_store:
	$(CD) $(DE_EPAGES_DIR) && $(MAKE) open_store STORE=$(STORE) STORE_TYPE=$(STORE_TYPE)
	$(DEL) $(TGT)\close_store\$(STORE)

preinstall_versions: $(DATA_DIR)\tgt\preinstall_versions
$(DATA_DIR)\tgt\preinstall_versions:
!ifeq ("$(STORES_OK)", "1")
	$(PRL) Scripts/buildCartridgeVersionFolders.pl -create -initial $(INITIAL_VERSION) -final $(PATCH_VERSION) -ini $(PREREQ_INI)
!ifdef WINDOWS
	echo BEGIN{$$ENV{EPAGES_CARTRIDGES} .= '/.version/$(PATCH_VERSION)';$$ENV{EPAGES_BACKUP_DIR} = '';} > Scripts\set_cartridge_dir
!else
!BEGIN_VERBATIM
	echo "BEGIN{\$$ENV{EPAGES_CARTRIDGES} .= '/.version/$(PATCH_VERSION)';\$$ENV{EPAGES_BACKUP_DIR} = '';}" > Scripts/set_cartridge_dir
!END_VERBATIM
!endif
	$(MAKE) build_plx NAME=installStoreType SCRIPT=_CARTRIDGES_\DE_EPAGES\Installer\Scripts\installStoreType.pl $(INSTALL_STORETYPE_OPTIONS)
	$(MAKE) build_plx NAME=DictionaryConverter SCRIPT=_CARTRIDGES_\DE_EPAGES\JQuery\Scripts\DictionaryConverter.pl
	$(PRL) $(INCLUDES) Scripts/installStoreType.plx ALL -storetype all -version $(PATCH_VERSION)
	$(PRL) $(INCLUDES) Scripts/SetStoreTypeLanguages.pl -version $(PATCH_VERSION) -lang "$(LANGUAGES_STORETYPE)"
	$(PRL) $(INCLUDES) Scripts/DictionaryConverter.plx -cartridge ALL -storetype all -version $(PATCH_VERSION)
	$(MAKE) run_plx NAME=buildDojo SCRIPT=$(DE_EPAGES_DIR)\Dojo\Scripts\build.pl
	$(MAKE) run_plx NAME=buildJS   SCRIPT=$(DE_EPAGES_DIR)\Presentation\Scripts\buildJS.pl
	$(MAKE) run_plx NAME=buildCSS  SCRIPT=$(DE_EPAGES_DIR)\Presentation\Scripts\buildCSS.pl
	$(MAKE) touch DIR=$(@D) ADDF=$(@F)
!endif

build_plx:
	$(COPY_FILE) Scripts/set_cartridge_dir Scripts/$(NAME).plx
	$(CAT) $(SCRIPT) >> Scripts/$(NAME).plx

run_plx:
	$(MAKE) build_plx
	$(PRL) $(INCLUDES) Scripts/$(NAME).plx -storetype all -version $(PATCH_VERSION)

patch_site:
!ifndef EPAGES_IGNORE_SITE
	$(PRL) Scripts/patchByVersion.pl -sync -storename Site -sitename Site -callscript Scripts/patchToVersion.pl\
 -ini $(PREREQ_INI) -final $(PATCH_VERSION) -target $(DATA_DIR)\tgt\patchByVersion -lang "$(LANGUAGES_STORES)"
!endif
!ifdef INITIAL_VERSION_LT_6010000000
	$(PRL) $(DE_EPAGES_DIR)/Object/Scripts/deleteObject.pl -nosync -storename Site -path /FeatureRefs/Invoice
	$(PRL) $(DE_EPAGES_DIR)/Object/Scripts/deleteObject.pl -nosync -storename Site -path /FeatureRefs/PackingSlip
	$(PRL) $(DE_EPAGES_DIR)/Object/Scripts/deleteObject.pl -nosync -storename Site -path /FeatureRefs/CreditNote
!endif

patch_stores: loop_stores.mak
	$(MAKE) build_plx NAME=UninstallIfExists SCRIPT=Scripts\UninstallIfExists.pl
	$(MAKE) -f loop_stores.mak patch_stores TGT="$(TGT)"
!ifdef INITIAL_VERSION_LT_6012000000
	$(IF_EXIST) $(DE_EPAGES_NEW)\DemoContent $(DO) $(RMDIR) $(DE_EPAGES_NEW)\DemoContent
	$(IF_EXIST) $(DE_EPAGES_NEW)\Google $(DO) $(RMDIR) $(DE_EPAGES_NEW)\Google
!endif

patch_store:
	$(PRL) Scripts/patchByVersion.pl -sync -storename $(STORE) -sitename Site -callscript Scripts/patchToVersion.pl\
 -ini $(PREREQ_INI) -final $(PATCH_VERSION) -target $(DATA_DIR)\tgt\patchByVersion -lang "$(LANGUAGES_STORES)"
!ifdef INITIAL_VERSION_LT_6012000000
	$(PRL) $(INCLUDES) Scripts/UninstallIfExists.plx -cartridge DE_EPAGES::DemoContent -storename $(STORE) -version $(PATCH_VERSION)
!endif

patch_pooldb:
	$(CD) $(DE_EPAGES_DIR) && $(MAKE) patch_store STORE=ASPoolDB STORE_TYPE=ASPoolDB DOJOBUILD=0

sync_stores: loop_stores.mak
!ifndef EPAGES_IGNORE_SITE
	$(MAKE) sync_store STORE=Site
!endif
	$(MAKE) -f loop_stores.mak sync_stores TGT="$(TGT)"
sync_store:
	$(CD) $(DE_EPAGES_DIR) && $(MAKE) synchronize STORE=$(STORE)

restore_styles: loop_stores.mak
	$(MAKE) -f loop_stores.mak restore_styles TGT="$(TGT)"
restore_style:
	$(PRL) $(DE_EPAGES_DIR)/Design/Scripts/invalidateAllStyles.pl -storename $(STORE)

create_ctmpls: loop_stores.mak
!ifndef EPAGES_IGNORE_SITE
	$(CREATE_CTMPLS) -storename Site -nooutput
!endif
	$(MAKE) -f loop_stores.mak create_ctmpls TGT="$(TGT)"
create_ctmpl:
	$(CREATE_CTMPLS) -storename $(STORE) -nooutput

update_ctmpls: loop_stores.mak
!ifndef EPAGES_IGNORE_SITE
!ifdef CTMPL_TXT
	$(CREATE_CTMPLS) -storename Site -listfile ctmpl-Site.txt -nooutput
!else
	$(CREATE_CTMPLS) -storename Site -delete -nooutput
!endif
!ifdef DEL_SAVED_INCLUDES
	$(IF_EXIST) $(EPAGES_STATIC)\Site\SavedIncludes $(DO) $(RMDIR) $(EPAGES_STATIC)\Site\SavedIncludes
!endif
!endif
	$(MAKE) -f loop_stores.mak update_ctmpls TGT="$(TGT)"
update_ctmpl:
!ifdef CTMPL_TXT
	$(CREATE_CTMPLS) -storename $(STORE) -listfile ctmpl-$(STORE).txt -nooutput
!else
	$(CREATE_CTMPLS) -storename $(STORE) -delete -nooutput
!endif
!ifdef DEL_SAVED_INCLUDES
	$(IF_EXIST) $(EPAGES_STATIC)\$(STORE)\SavedIncludes $(DO) $(RMDIR) $(EPAGES_STATIC)\$(STORE)\SavedIncludes
!endif

test_styles: loop_stores.mak
	$(MAKE) -f loop_stores.mak test_styles TGT="$(TGT)"
test_style:
	$(PRL) $(DE_EPAGES_DIR)/Installer/Scripts/compareCartridgeData.pl -storename $(STORE) -type $(STORE_TYPE)

make_makefile:
	$(CD) $(DE_EPAGES_DIR) && $(PRL) Makefile.PL

loop_stores.mak:
	$(LOOP_STORES) -mak makefile> $@.out
	$(MOVE) $@.out $@

update_cartridge_dir:
	$(PRL) -I"$(EPAGES_CARTRIDGES)\.version\$(PATCH_VERSION)" Scripts/buildCartridgeVersionFolders.pl\
 -update -initial $(INITIAL_VERSION) -final $(PATCH_VERSION) -ini $(PREREQ_INI)
!ifeq ("$(CHANGE_PERL)", "1")
	$(MAKE) Perl\patch
!endif
!ifndef WINDOWS
!BEGIN_VERBATIM
	chown -R ep_appl:epages "$(EPAGES_CARTRIDGES)/"
	find "$(EPAGES_CARTRIDGES)" -type f -name '*.??.xml' -exec chmod 644 {} \;
	chmod 644 "$(EPAGES_CARTRIDGES)"/*/*/Data/Public/BO/*.??.dot
!END_VERBATIM
!endif

patch_version:
	echo $(PATCH_TAG)>> $(EPAGES_CONFIG)\version.txt

# auxiliary targets
# *****************

stop_cron:
!ifneq ("$(PATCH_LEVEL)", "0")
	$(IF_NOT_EXIST) "$(DATA_DIR)"\tgt\prehosts.txt $(DO) $(PRL) Scripts/EditSchedulerConf.pl -stop $(CRON_FILES)
!endif
	$(MAKE) stop_sic

start_cron:
!ifneq ("$(PATCH_LEVEL)", "0")
	$(PRL) Scripts/EditSchedulerConf.pl -start $(CRON_FILES)
!endif
	$(MAKE) start_sic

start_sic: $(TGT)\start_sic
$(TGT)\start_sic:
!ifeq ("$(CHANGE_SIC)", "1")
	$(START_SIC)
	$(MAKE) touch DIR=$(@D) ADDF=$(@F)
!endif

stop_sic:
!ifeq ("$(CHANGE_SIC)", "1")
	$(STOP_SIC)
	$(DEL) $(TGT)\start_sic
!endif

stop_web:
!ifeq ("$(PATCH_LEVEL)", "0")
!ifdef APACHE_OS
	$(APACHE_STOP)
!else
	$(STOP_SERVICE) webserver
!endif
!ifndef WINDOWS
!BEGIN_VERBATIM
	-kill $$(ps -u$(EPAGES_WEBUSER) -uep_web -opid= -oppid= -ocomm= 2>/dev/null | while read pid ppid comm ;\
 do [ "$${comm#httpd}" != "$$comm" ] && echo -e "$$pid\n$$ppid" ; done | sort | uniq | tr '\n' ' ') 2>/dev/null
!END_VERBATIM
!endif
!endif

start_web:
!ifeq ("$(PATCH_LEVEL)", "0")
!ifdef CONFIGURE_HTTPD
	$(MAKE) configure_httpd
!endif
!ifdef APACHE_OS
	$(APACHE_START)
!else
	$(START_SERVICE) webserver
!endif
!endif

stop_epages: .force stop_web
!ifeq ("$(PATCH_LEVEL)", "0")
	$(STOP_SERVICE) cron
	$(STOP_SERVICE) epages
!ifndef WINDOWS
	if pgrep RequestRouter ; then $(ETC_INITD) stop_rr || pkill -9 RequestRouter ; fi
!endif
!endif

start_epages: .force start_web
!ifeq ("$(PATCH_LEVEL)", "0")
	$(START_SERVICE) epages
	$(START_SERVICE) cron
!endif

restart_epages:
!ifneq ("$(PATCH_LEVEL)", "0")
!ifdef IS_ALPHA
	$(PRL) $(DE_EPAGES_DIR)/WebInterface/Scripts/shutdownAppSrv.pl -sleep 0
!endif
!endif

limit_httpd unlimit_httpd new/limit_httpd new/unlimit_httpd:
!ifdef LIMIT_HTTPD
!ifdef APACHE_CONF
	sh Apache/$(@F).sh -v "$(@D)" -c host-$(HOSTNAME).mk -i "$(INITIAL_INTERNAL_VERSION)"
	$(APACHE_START)
!endif
!endif

configure_httpd:
!ifdef WINDOWS
!ifdef INITIAL_VERSION_LT_6012000000
	cscript Scripts\ConfigureIIS.vbs
!endif
!else
!ifdef APACHE_CONF
	sh Apache/$(@F).sh -c host-$(HOSTNAME).mk -i "$(INITIAL_INTERNAL_VERSION)"
!endif
!endif

configure_apache:
!ifdef APACHE_OS_CONFD
	$(PRL) Scripts/PatchConfig.pl -source Apache/extra-os -target "$(APACHE_OS_CONFD)" -version $(PATCH_VERSION)
	$(APACHE_START)
!endif
!ifdef APACHE_EPAGES_CONFD
	$(PRL) Scripts/PatchConfig.pl -source Apache/extra-ep -target "$(APACHE_EPAGES_CONFD)" -version $(PATCH_VERSION)
!endif

update_repo:
!ifndef WINDOWS
	sh Scripts/UpdateRepo.sh $(DATA_DIR)/tgt/alphahost.txt $(DATA_DIR)/tgt/prehosts.txt
!endif

perm:
!ifndef WINDOWS
	-$(ETC_INITD) perm admin
!endif

touch:
	$(MKDIR) $(DIR)
	$(DEL) $(DIR)\$(DELF)
	$(ECHONL) > $(DIR)\$(ADDF)

del_backup_files:
!ifneq ("$(BACKUP_DIR)", "")
	$(IF_EXIST) "$(BACKUP_DIR)" $(DO) $(RMDIR) "$(BACKUP_DIR)"
!endif
	$(IF_EXIST) "$(DATA_DIR)\tgt" $(DO) $(RMDIR) "$(DATA_DIR)\tgt"
	$(IF_EXIST) "$(DATA_DIR)\Config" $(DO) $(RMDIR) "$(DATA_DIR)\Config"
	$(IF_EXIST) "$(DATA_DIR)\DE_EPAGES" $(DO) $(RMDIR) "$(DATA_DIR)\DE_EPAGES"
	$(DEL) "$(DATA_DIR)\Cartridges.xml"
	$(PRL) Scripts/DeleteOldStoreTypeDirs.pl -current $(PATCH_VERSION)
	$(IF_EXIST) "$(EPAGES_CARTRIDGES)\.version" $(DO) $(RMDIR) "$(EPAGES_CARTRIDGES)\.version"
	$(IF_EXIST) "$(EPAGES_CARTRIDGES)\.lang" $(DO) $(RMDIR) "$(EPAGES_CARTRIDGES)\.lang"
	$(DEL) $(EPAGES_CARTRIDGES)/.6.*
	$(DEL) $(EPAGES_SHARED)/Monitor/.6.*
	$(DEL) $(EPAGES_STORES)/.6.*
	$(DEL) $(EPAGES_WEBROOT)/.6.*
	$(DEL) $(EPAGES_CONFIG)/.6.*
	$(DEL) $(EPAGES)/Service/.6.*
	$(DEL) $(EPAGES)/RequestRouter/.6.*
	$(DEL) $(EPAGES)/WebAdapter/.6.*
	$(DEL) $(HTTPD_ROOT)/.6.*
	$(DEL) $(EPAGES_PERL)/.6.*
	$(DEL) $(SYBASE)/.6.*
	$(DEL) $(SYBASE)/bin/.6.*
	$(DEL) $(EPAGES)/bin/.6.*
!ifndef WINDOWS
	$(DEL) `dirname $(EPAGES)`/etc/.6.*
!endif

#-*- Makefile -*-
